==> hbase-2.4.9-src.tar.gz: hbase-2.4.9/hbase-server/src/main/java/org/apache/hadoop/hbase/wal/NamespaceGroupingStrategy.java <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.wal;

import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.hbase.NamespaceDescriptor;
import org.apache.yetus.audience.InterfaceAudience;
import org.apache.hadoop.hbase.util.Bytes;
import org.apache.hadoop.hbase.wal.RegionGroupingProvider.RegionGroupingStrategy;

/**
 * A WAL grouping strategy based on namespace.
 * Notice: the wal-group mapping might change if we support dynamic namespace updating later,
 * and special attention needed if we support feature like group-based replication.
 */
@InterfaceAudience.Private
public class NamespaceGroupingStrategy implements RegionGroupingStrategy {
  String providerId;

  @Override
  public String group(byte[] identifier, byte[] namespace) {
    String namespaceString;
    if (namespace == null || namespace.length == 0) {
      namespaceString = NamespaceDescriptor.DEFAULT_NAMESPACE_NAME_STR;
    } else {
      namespaceString = Bytes.toString(namespace);
    }
    return providerId + GROUP_NAME_DELIMITER + namespaceString;
  }

  @Override
  public void init(Configuration config, String providerId) {
    this.providerId = providerId;
  }

}

==> hbase-2.6.3-src.tar.gz: hbase-2.6.3/hbase-server/src/main/java/org/apache/hadoop/hbase/wal/NamespaceGroupingStrategy.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.wal;

import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.hbase.NamespaceDescriptor;
import org.apache.hadoop.hbase.util.Bytes;
import org.apache.hadoop.hbase.wal.RegionGroupingProvider.RegionGroupingStrategy;
import org.apache.yetus.audience.InterfaceAudience;

/**
 * A WAL grouping strategy based on namespace. Notice: the wal-group mapping might change if we
 * support dynamic namespace updating later, and special attention needed if we support feature like
 * group-based replication.
 */
@InterfaceAudience.Private
public class NamespaceGroupingStrategy implements RegionGroupingStrategy {
  String providerId;

  @Override
  public String group(byte[] identifier, byte[] namespace) {
    String namespaceString;
    if (namespace == null || namespace.length == 0) {
      namespaceString = NamespaceDescriptor.DEFAULT_NAMESPACE_NAME_STR;
    } else {
      namespaceString = Bytes.toString(namespace);
    }
    return providerId + GROUP_NAME_DELIMITER + namespaceString;
  }

  @Override
  public void init(Configuration config, String providerId) {
    this.providerId = providerId;
  }

}
